@@ -13,7 +13,7 @@
 struct tm *
 Gmtime(time_t t, struct tm *const tp)
 {
-#if defined(HAVE_GMTIME_R)
+#if defined(HAVE_GMTIME_R) && !defined(MACOSX)
 	if (t == 0)
 		time(&t);
 	if (gmtime_r(&t, tp) != NULL)
